@@ -89,9 +89,7 @@ pub fn reverse_derivative(
                     .get(&operation_sig)
                     .expect("reverse_derivative: unsupported operation");
                 // Applies the forward deriative function for the found operation.
-                let new_stmt = operation_out_signature.reverse_derivative.expect(
-                    "reverse_derivative: binary expression unimplemented forward deriative",
-                )(&stmt, component_map);
+                let new_stmt = (operation_out_signature.reverse_derivative)(&stmt, component_map);
                 return new_stmt;
             } else if let syn::Expr::Call(call_expr) = &*init.1 {
                 // Create function in signature
@@ -101,24 +99,14 @@ pub fn reverse_derivative(
                     .get(&function_in_signature)
                     .expect("reverse_derivative: unsupported function");
                 // Gets new stmt
-                let new_stmt = function_out_signature
-                    .reverse_derivative
-                    .expect("reverse_derivative: binary unimplemented forward")(
-                    &stmt,
-                    component_map,
-                );
+                let new_stmt = (function_out_signature.reverse_derivative)(&stmt, component_map);
                 return new_stmt;
             } else if let syn::Expr::MethodCall(method_expr) = &*init.1 {
                 let method_sig = method_signature(method_expr, type_map);
                 let method_out = SUPPORTED_METHODS
                     .get(&method_sig)
                     .expect("reverse_derivative: unsupported method");
-                let new_stmt = method_out
-                    .reverse_derivative
-                    .expect("reverse_derivative: method unimplemented forward")(
-                    &stmt,
-                    component_map,
-                );
+                let new_stmt = (method_out.reverse_derivative)(&stmt, component_map);
                 return new_stmt;
             } else if let syn::Expr::Path(expr_path) = &*init.1 {
                 // Variable identifier
